#  MI Configurator

This is a service used to load and manage configuration data for Model Integration
applications.

### Installation

Create or use a python 3.13+ environment.

% pip install mi-configurator

